@@ -346,6 +346,7 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
+    print('key',key)
     response = yield _get_object(context, context.s3_bucket, key)
     print(response)
     file_bytes = response['Body']
@@ -368,6 +369,7 @@ def _get_any(context, path, content, type, mimetype, format, decode):
 @gen.coroutine
 def _get_directory(context, path, content):
     key = _key(context, path)
+    print('indir',key)
     key_prefix = key if (key == '' or key[-1] == '/') else (key + '/')
     keys, directories = \
         (yield _list_immediate_child_keys_and_directories(context, key_prefix)) if content else \
